@@ -27,6 +27,7 @@ from grpc.experimental import aio  # type: ignore
 from google.cloud.documentai_v1.types import document_processor_service
 from google.cloud.documentai_v1.types import processor
 from google.cloud.documentai_v1.types import processor as gcd_processor
+from google.cloud.documentai_v1.types import processor_type
 
 from .base import DEFAULT_CLIENT_INFO, DocumentProcessorServiceTransport
 from .grpc import DocumentProcessorServiceGrpcTransport
@@ -374,6 +375,35 @@ class DocumentProcessorServiceGrpcAsyncIOTransport(DocumentProcessorServiceTrans
             )
         return self._stubs["list_processor_types"]
 
+    @property
+    def get_processor_type(
+        self,
+    ) -> Callable[
+        [document_processor_service.GetProcessorTypeRequest],
+        Awaitable[processor_type.ProcessorType],
+    ]:
+        r"""Return a callable for the get processor type method over gRPC.
+
+        Gets a processor type detail.
+
+        Returns:
+            Callable[[~.GetProcessorTypeRequest],
+                    Awaitable[~.ProcessorType]]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "get_processor_type" not in self._stubs:
+            self._stubs["get_processor_type"] = self.grpc_channel.unary_unary(
+                "/google.cloud.documentai.v1.DocumentProcessorService/GetProcessorType",
+                request_serializer=document_processor_service.GetProcessorTypeRequest.serialize,
+                response_deserializer=processor_type.ProcessorType.deserialize,
+            )
+        return self._stubs["get_processor_type"]
+
     @property
     def list_processors(
         self,
